==> nuxt-graphql-middleware-1.1.5.tgz: package/lib/esm/module/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import path from 'path';
import fs from 'fs';
import mkdirp from 'mkdirp';
import chokidar from 'chokidar';
import consola from 'consola';
import serverMiddleware from './../serverMiddleware';
import graphqlImport from './graphqlImport';
import codegen from './codegen';
const logger = consola.withTag('nuxt-graphql-middleware');
const PLUGIN_PATH = path.resolve(__dirname, './../plugin/index.js');
var FileType;
(function (FileType) {
    FileType["Query"] = "query";
    FileType["Mutation"] = "mutation";
})(FileType || (FileType = {}));
function resolveGraphqlFile(file, resolver) {
    return fs.promises
        .readFile(file)
        .then((buffer) => buffer.toString())
        .then((source) => graphqlImport(source, resolver));
}
function writeSource(dest, filePath, source) {
    const fileName = path.basename(filePath);
    const out = path.resolve(dest, fileName);
    return fs.promises.writeFile(out, source);
}
function resolveGraphql(files, map, resolver, filesMap, type, outputPath) {
    return Promise.all(Object.keys(files).map((name) => {
        const filePath = files[name];
        const file = resolver(filePath);
        return resolveGraphqlFile(file, resolver).then((source) => {
            map.set(name, source);
            if (outputPath) {
                writeSource(outputPath, filePath, source);
            }
            filesMap.set(file, {
                type,
                name,
                file: filePath,
            });
        });
    }));
}
export const graphqlMiddleware = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t;
    return __awaiter(this, void 0, void 0, function* () {
        const resolver = this.nuxt.resolver.resolveAlias;
        const options = this.options;
        const PORT = ((_b = (_a = this.options) === null || _a === void 0 ? void 0 : _a.server) === null || _b === void 0 ? void 0 : _b.port) || 3000;
        const provided = (this.options.graphqlMiddleware ||
            {});
        const config = {
            graphqlServer: provided.graphqlServer || '',
            typescript: {
                enabled: !!((_c = provided.typescript) === null || _c === void 0 ? void 0 : _c.enabled),
                schemaOptions: (_d = provided.typescript) === null || _d === void 0 ? void 0 : _d.schemaOptions,
                resolvedQueriesPath: ((_e = provided.typescript) === null || _e === void 0 ? void 0 : _e.resolvedQueriesPath) || provided.outputPath || '',
                schemaOutputPath: ((_f = provided.typescript) === null || _f === void 0 ? void 0 : _f.schemaOutputPath) || '~/schema',
                typesOutputPath: ((_g = provided.typescript) === null || _g === void 0 ? void 0 : _g.typesOutputPath) || '~/types',
                skipSchemaDownload: !!((_h = provided.typescript) === null || _h === void 0 ? void 0 : _h.skipSchemaDownload),
            },
            endpointNamespace: provided.endpointNamespace || '/__graphql_middleware',
            debug: provided.debug || options.dev,
            queries: provided.queries || {},
            mutations: provided.mutations || {},
            outputPath: provided.outputPath || '',
            server: provided.server,
            plugin: {
                enabled: !!((_j = provided.plugin) === null || _j === void 0 ? void 0 : _j.enabled),
                cacheInBrowser: !!((_k = provided.plugin) === null || _k === void 0 ? void 0 : _k.cacheInBrowser),
                cacheInServer: !!((_l = provided.plugin) === null || _l === void 0 ? void 0 : _l.cacheInServer),
            },
        };
        if ((_m = config.plugin) === null || _m === void 0 ? void 0 : _m.enabled) {
            this.addPlugin({
                src: PLUGIN_PATH,
                options: {
                    namespace: config.endpointNamespace,
                    port: PORT,
                    cacheInBrowser: ((_o = config.plugin) === null || _o === void 0 ? void 0 : _o.cacheInBrowser) ? 'true' : 'false',
                    cacheInServer: ((_p = config.plugin) === null || _p === void 0 ? void 0 : _p.cacheInServer) ? 'true' : 'false',
                },
            });
        }
        const fileMap = new Map();
        const queries = new Map();
        const mutations = new Map();
        const outputPath = config.outputPath ? resolver(config.outputPath) : '';
        yield mkdirp(outputPath);
        const schemaOutputPath = resolver((_q = config.typescript) === null || _q === void 0 ? void 0 : _q.schemaOutputPath);
        const typesOutputPath = resolver((_r = config.typescript) === null || _r === void 0 ? void 0 : _r.typesOutputPath);
        const { generateSchema, generateTypes } = codegen(config.graphqlServer, {
            resolvedQueriesPath: config.outputPath,
            schemaOptions: (_s = config.typescript) === null || _s === void 0 ? void 0 : _s.schemaOptions,
            schemaOutputPath,
            typesOutputPath,
        });
        if ((_t = config.typescript) === null || _t === void 0 ? void 0 : _t.enabled) {
            if (!outputPath) {
                throw new Error('TypeScript enabled, but no outputPath given.');
            }
            yield mkdirp(schemaOutputPath);
            yield generateSchema();
        }
        function build() {
            logger.log('Building GraphQL files...');
            return Promise.all([
                resolveGraphql(config.queries, queries, resolver, fileMap, FileType.Query, outputPath),
                resolveGraphql(config.mutations, mutations, resolver, fileMap, FileType.Mutation, outputPath),
            ]).then(() => {
                var _a;
                logger.success('Finished building GraphQL files');
                if ((_a = config.typescript) === null || _a === void 0 ? void 0 : _a.enabled) {
                    return generateTypes().then(() => {
                        logger.success('Finished generating GraphQL TypeScript files.');
                    });
                }
            });
        }
        function watchFiles() {
            const ignored = ['node_modules', '.nuxt'];
            if (config.outputPath) {
                ignored.push(config.outputPath);
            }
            const filesWatcher = chokidar.watch('./**/*.graphql', {
                ignoreInitial: true,
                ignored,
            });
            if (filesWatcher) {
                logger.info('Watching for query changes');
                filesWatcher.on('change', () => {
                    build();
                });
            }
            return filesWatcher;
        }
        let watcher;
        if (this.nuxt.options.dev) {
            this.nuxt.hook('build:done', () => {
                watcher = watchFiles();
            });
            this.nuxt.hook('close', () => {
                if (watcher) {
                    watcher.close();
                    watcher = undefined;
                }
            });
        }
        build().then(() => {
            if (options.debug) {
                logger.info('Available queries and mutations:');
                console.table(Array.from(fileMap.entries()).map(([_key, value]) => value));
            }
        });
        this.addServerMiddleware({
            path: config.endpointNamespace,
            handler: serverMiddleware(config.graphqlServer, queries, mutations, config.server),
        });
    });
};

==> nuxt-graphql-middleware-1.1.7.tgz: package/lib/esm/module/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import path from 'path';
import fs from 'fs';
import mkdirp from 'mkdirp';
import chokidar from 'chokidar';
import consola from 'consola';
import serverMiddleware from './../serverMiddleware';
import graphqlImport from './graphqlImport';
import codegen from './codegen';
const logger = consola.withTag('nuxt-graphql-middleware');
const PLUGIN_PATH = path.resolve(__dirname, './../plugin/index.js');
var FileType;
(function (FileType) {
    FileType["Query"] = "query";
    FileType["Mutation"] = "mutation";
})(FileType || (FileType = {}));
function resolveGraphqlFile(file, resolver) {
    return fs.promises
        .readFile(file)
        .then((buffer) => buffer.toString())
        .then((source) => graphqlImport(source, resolver));
}
function writeSource(dest, filePath, source) {
    const fileName = path.basename(filePath);
    const out = path.resolve(dest, fileName);
    return fs.promises.writeFile(out, source);
}
function resolveGraphql(files, map, resolver, filesMap, type, outputPath) {
    return Promise.all(Object.keys(files).map((name) => {
        const filePath = files[name];
        const file = resolver(filePath);
        return resolveGraphqlFile(file, resolver).then((source) => {
            map.set(name, source);
            if (outputPath) {
                writeSource(outputPath, filePath, source);
            }
            filesMap.set(file, {
                type,
                name,
                file: filePath,
            });
        });
    }));
}
export const graphqlMiddleware = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u;
    return __awaiter(this, void 0, void 0, function* () {
        const resolver = this.nuxt.resolver.resolveAlias;
        const options = this.options;
        const PORT = ((_b = (_a = this.options) === null || _a === void 0 ? void 0 : _a.server) === null || _b === void 0 ? void 0 : _b.port) || 3000;
        const provided = (this.options.graphqlMiddleware ||
            {});
        const config = {
            graphqlServer: provided.graphqlServer || '',
            typescript: {
                enabled: !!((_c = provided.typescript) === null || _c === void 0 ? void 0 : _c.enabled),
                schemaOptions: (_d = provided.typescript) === null || _d === void 0 ? void 0 : _d.schemaOptions,
                resolvedQueriesPath: ((_e = provided.typescript) === null || _e === void 0 ? void 0 : _e.resolvedQueriesPath) || provided.outputPath || '',
                schemaOutputPath: ((_f = provided.typescript) === null || _f === void 0 ? void 0 : _f.schemaOutputPath) || '~/schema',
                typesOutputPath: ((_g = provided.typescript) === null || _g === void 0 ? void 0 : _g.typesOutputPath) || '~/types',
                skipSchemaDownload: !!((_h = provided.typescript) === null || _h === void 0 ? void 0 : _h.skipSchemaDownload),
            },
            endpointNamespace: provided.endpointNamespace || '/__graphql_middleware',
            debug: provided.debug || options.dev,
            queries: provided.queries || {},
            mutations: provided.mutations || {},
            outputPath: provided.outputPath || '',
            server: provided.server,
            plugin: {
                enabled: !!((_j = provided.plugin) === null || _j === void 0 ? void 0 : _j.enabled),
                cacheInBrowser: !!((_k = provided.plugin) === null || _k === void 0 ? void 0 : _k.cacheInBrowser),
                cacheInServer: !!((_l = provided.plugin) === null || _l === void 0 ? void 0 : _l.cacheInServer),
            },
        };
        if ((_m = config.plugin) === null || _m === void 0 ? void 0 : _m.enabled) {
            this.addPlugin({
                src: PLUGIN_PATH,
                options: {
                    namespace: config.endpointNamespace,
                    port: PORT,
                    cacheInBrowser: ((_o = config.plugin) === null || _o === void 0 ? void 0 : _o.cacheInBrowser) ? 'true' : 'false',
                    cacheInServer: ((_p = config.plugin) === null || _p === void 0 ? void 0 : _p.cacheInServer) ? 'true' : 'false',
                },
            });
        }
        const fileMap = new Map();
        const queries = new Map();
        const mutations = new Map();
        const outputPath = config.outputPath ? resolver(config.outputPath) : '';
        yield mkdirp(outputPath);
        const schemaOutputPath = resolver((_q = config.typescript) === null || _q === void 0 ? void 0 : _q.schemaOutputPath);
        const typesOutputPath = resolver((_r = config.typescript) === null || _r === void 0 ? void 0 : _r.typesOutputPath);
        const { generateSchema, generateTypes } = codegen(config.graphqlServer, {
            resolvedQueriesPath: config.outputPath,
            schemaOptions: (_s = config.typescript) === null || _s === void 0 ? void 0 : _s.schemaOptions,
            skipSchemaDownload: (_t = config.typescript) === null || _t === void 0 ? void 0 : _t.skipSchemaDownload,
            schemaOutputPath,
            typesOutputPath,
        });
        if ((_u = config.typescript) === null || _u === void 0 ? void 0 : _u.enabled) {
            if (!outputPath) {
                throw new Error('TypeScript enabled, but no outputPath given.');
            }
            yield mkdirp(schemaOutputPath);
            yield generateSchema();
        }
        function build() {
            logger.log('Building GraphQL files...');
            return Promise.all([
                resolveGraphql(config.queries, queries, resolver, fileMap, FileType.Query, outputPath),
                resolveGraphql(config.mutations, mutations, resolver, fileMap, FileType.Mutation, outputPath),
            ]).then(() => {
                var _a;
                logger.success('Finished building GraphQL files');
                if ((_a = config.typescript) === null || _a === void 0 ? void 0 : _a.enabled) {
                    return generateTypes().then(() => {
                        logger.success('Finished generating GraphQL TypeScript files.');
                    });
                }
            });
        }
        function watchFiles() {
            const ignored = ['node_modules', '.nuxt'];
            if (config.outputPath) {
                ignored.push(config.outputPath);
            }
            const filesWatcher = chokidar.watch('./**/*.graphql', {
                ignoreInitial: true,
                ignored,
            });
            if (filesWatcher) {
                logger.info('Watching for query changes');
                filesWatcher.on('change', () => {
                    build();
                });
            }
            return filesWatcher;
        }
        let watcher;
        if (this.nuxt.options.dev) {
            this.nuxt.hook('build:done', () => {
                watcher = watchFiles();
            });
            this.nuxt.hook('close', () => {
                if (watcher) {
                    watcher.close();
                    watcher = undefined;
                }
            });
        }
        build().then(() => {
            if (options.debug) {
                logger.info('Available queries and mutations:');
                console.table(Array.from(fileMap.entries()).map(([_key, value]) => value));
            }
        });
        this.addServerMiddleware({
            path: config.endpointNamespace,
            handler: serverMiddleware(config.graphqlServer, queries, mutations, config.server),
        });
    });
};
